@@ -5,12 +5,12 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 )
 
 func TestSymlinks(t *testing.T) {
 	pwd, err := os.Getwd()
-	require.NoError(t, err)
+	assert.NoError(t, err)
 	expected := []string{
 		filepath.Join(pwd, "testdata/three"),
 		filepath.Join(pwd, "testdata/sub/two"),
@@ -18,6 +18,6 @@ func TestSymlinks(t *testing.T) {
 		filepath.Join(pwd, "testdata/dest"),
 	}
 	actual, err := ResolveSymlinks("testdata/three")
-	require.NoError(t, err)
-	require.Equal(t, expected, actual)
+	assert.NoError(t, err)
+	assert.Equal(t, expected, actual)
 }
